pub struct Instance {
pub raw: Arc<RawInstance>,
pub extensions: Vec<&'static CStr>,
pub entry: Entry,
}Fields
raw: Arc<RawInstance>extensions: Vec<&'static CStr>Supported extensions of this instance.
entry: EntryImplementations
Sourceimpl Instance
impl Instance
pub fn create_surface_from_xlib( &self, dpy: *mut Display, window: Window, ) -> Surface
pub fn create_surface_from_xcb( &self, connection: *mut xcb_connection_t, window: xcb_window_t, ) -> Surface
pub fn create_surface_from_wayland( &self, display: *mut c_void, surface: *mut c_void, ) -> Surface
pub fn create_surface_from_vk_surface_khr(&self, surface: SurfaceKHR) -> Surface
Sourceimpl Instance
impl Instance
pub fn required_extensions( entry: &Entry, driver_api_version: Version, ) -> Result<Vec<&'static CStr>, UnsupportedBackend>
pub fn required_layers( entry: &Entry, ) -> Result<Vec<&'static CStr>, UnsupportedBackend>
Sourcepub unsafe fn from_raw(
entry: Entry,
raw_instance: Instance,
driver_api_version: Version,
extensions: Vec<&'static CStr>,
) -> Result<Self, UnsupportedBackend>
pub unsafe fn from_raw( entry: Entry, raw_instance: Instance, driver_api_version: Version, extensions: Vec<&'static CStr>, ) -> Result<Self, UnsupportedBackend>
Safety
raw_instance must be created using at least the extensions provided by Instance::required_extensions()
and the layers provided by Instance::required_extensions().
driver_api_version must match the version used to create raw_instance.
extensions must match the extensions used to create raw_instance.
raw_instance must be manually destroyed after gfx-hal Instance has been dropped.
Sourcepub unsafe fn adapter_from_raw(
&self,
raw_physical_device: PhysicalDevice,
) -> Adapter<Backend>
pub unsafe fn adapter_from_raw( &self, raw_physical_device: PhysicalDevice, ) -> Adapter<Backend>
Safety
raw_physical_device must be created from self (or from the inner raw handle)